---
name: Style issue
about: Help us improve the Black style
title: ""
labels: "T: design"
assignees: ""
---

**Describe the style change**

<!-- A clear and concise description of how the style can be
improved. -->

**Examples in the current _Black_ style**

<!-- Think of some short code snippets that show
how the current _Black_ style is not great: -->

```python
def f():
    "Make sure this code is blackened"""
    pass
```

**Desired style**

<!-- How do you think _Black_ should format the above snippets: -->

```python
def f(
    ):
    pass
```

**Additional context**

<!-- Add any other context about the problem here. -->
